@@ -117,7 +117,7 @@ define('TEXT_DELETE_COUNT', 'оݥǡ%s濫ޤޤ');
 define('TEXT_DELETE_PRODUCTS_LIST', 'оݥǡ');
 define('TEXT_NOTES_TO_INPUT_PRODUCTS_MODELS', 'ɤϣԣɤǵƤ');
 
-define('TEXT_UPLOAD_CONFIRMATION', 'åץɥܥ򲡤ȡåץɥեƤǧޤ');
+define('TEXT_UPLOAD_CONFIRMATION', 'ܥ򲡤ȡåץɥեƤǧޤ');
 define('TEXT_UPLOAD_CONFIG_ERROR_NOTICE', '嵭ΤȤꥢåץե˥顼ޤåץեƤ');
 define('TEXT_DOWNLOAD_CONFIRMATION', 'ܥ򲡤ȡɥեκϤޤ');
 define('TEXT_DOWNLOAD_CONFIG_ERROR_NOTICE', '嵭ΤȤե˥顼ޤեƤ');
