@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: account.php,v 1.2 2005/08/19 09:48:11 ryu Exp $
+  $Id: account.php,v 1.3 2006/02/03 07:38:01 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -22,6 +22,25 @@
 
   require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_ACCOUNT);
 
+  switch ($HTTP_GET_VARS['action']) {
+    case 'delete_confirm':
+      $delete_text = '<div class="textBox" style="text-align: center;">' . TEXT_DELETE_ACCOUNT_CONFIRMATION . '<br>' . '<a href="' . tep_href_link(FILENAME_ACCOUNT, 'action=delete', 'SSL') . '">' . TEXT_DELETE_ACCOUNT2 . '</a></div>';
+      break;
+    case 'delete':
+      tep_db_query("delete from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . tep_db_input($customer_id) . "'");
+      tep_db_query("delete from " . TABLE_CUSTOMERS . " where customers_id = '" . tep_db_input($customer_id) . "'");
+      tep_db_query("delete from " . TABLE_CUSTOMERS_INFO . " where customers_info_id = '" . tep_db_input($customers_id) . "'");
+      tep_db_query("delete from " . TABLE_CUSTOMERS_BASKET . " where customers_id = '" . tep_db_input($customer_id) . "'");
+      tep_db_query("delete from " . TABLE_CUSTOMERS_BASKET_ATTRIBUTES . " where customers_id = '" . tep_db_input($customer_id) . "'");
+      tep_db_query("delete from " . TABLE_WHOS_ONLINE . " where customer_id = '" . tep_db_input($customer_id) . "'");
+      
+      tep_redirect(tep_href_link(FILENAME_ACCOUNT_DELETE_SUCCESS, '', 'SSL'));
+      break;
+    default:
+      $delete_text = '<p align="right"><a href="' . tep_href_link(FILENAME_ACCOUNT, 'action=delete_confirm', 'SSL') . '">' . TEXT_DELETE_ACCOUNT . '</a></p>';
+      break;
+  }
+
   $breadcrumb->add(NAVBAR_TITLE, tep_href_link(FILENAME_ACCOUNT, '', 'SSL'));
 ?>
 <!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
@@ -48,6 +67,8 @@
     <td id="mainContents">
       <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
 <?php
+  echo $delete_text;
+
   $is_read_only = true;
 
   $account_query = tep_db_query("select c.customers_gender, c.customers_firstname, c.customers_lastname, c.customers_dob, c.customers_email_address, a.entry_company, a.entry_street_address, a.entry_suburb, a.entry_postcode, a.entry_city, a.entry_zone_id, a.entry_state, a.entry_country_id, c.customers_telephone, c.customers_fax, c.customers_newsletter from " . TABLE_CUSTOMERS . " c, " . TABLE_ADDRESS_BOOK . " a where c.customers_id = '" . $customer_id . "' and a.customers_id = c.customers_id and a.address_book_id = '" . $customer_default_address_id . "'");
