@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: advanced_search_result.php,v 1.3 2005/08/19 09:48:12 ryu Exp $
+  $Id: advanced_search_result.php,v 1.5 2006/01/29 14:49:22 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -468,7 +468,7 @@
   } else {
     $sort_col = substr($HTTP_GET_VARS['sort'], 0 , 1);
     $sort_order = substr($HTTP_GET_VARS['sort'], 1);
-    $order_str = ' order by ';
+    $order_str = ' order by p.sort_order, ';
     switch ($column_list[$sort_col-1]) {
       case 'PRODUCT_LIST_MODEL':
         $order_str .= "p.products_model " . ($sort_order == 'd' ? "desc" : "") . ", pd.products_name";
@@ -514,6 +514,7 @@
 
   $listing_sql = $select_str . $from_str . $where_str . $order_str;
 
+  $option_search_engine_safe = false;
   require(DIR_WS_MODULES . FILENAME_PRODUCT_LISTING);
 ?>
       <table>
