@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_process.php,v 1.2 2005/10/28 00:52:14 ryu Exp $
+  $Id: checkout_process.php,v 1.3 2006/02/01 07:11:50 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -342,6 +342,9 @@
   $email_order .= "\n";
   
   if (KN_CFG_MAIL_PRIVACY_DISPLAY == 'true') {
+    $email_order .= "\n" . EMAIL_TEXT_CUSTOMER . "\n" . EMAIL_SEPARATOR . "\n";
+    $email_order .= EMAIL_TEXT_CUSTOMER_NAME . '  ' . tep_get_fullname($order->customer['firstname'],$order->customer['lastname']) . "\n";
+    $email_order .= EMAIL_TEXT_CUSTOMER_EMAIL_ADDRESS . '  ' . $order->customer['email_address'] . "\n";
     $email_order .= "\n" . EMAIL_TEXT_DELIVERY_ADDRESS . "\n" . 
                     EMAIL_SEPARATOR . "\n" .
                     tep_address_label($customer_id, $sendto, 0, '', "\n") . "\n";
