@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: order.php,v 1.1.1.1 2005/06/30 05:04:15 ryu Exp $
+  $Id: order.php,v 1.2 2006/02/01 07:31:31 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -191,13 +191,13 @@
                           'currency' => $currency,
                           'currency_value' => $currencies->currencies[$currency]['value'],
                           'payment_method' => $payment,
-                          'cc_type' => $GLOBALS['cc_type'],
-                          'cc_owner' => $GLOBALS['cc_owner'],
-                          'cc_number' => $GLOBALS['cc_number'],
-                          'cc_expires' => $GLOBALS['cc_expires'],
+                          'cc_type' => tep_db_prepare_input($_POST['cc_type']),
+                          'cc_owner' => tep_db_prepare_input($_POST['cc_owner']),
+                          'cc_number' => tep_db_prepare_input($_POST['cc_number']),
+                          'cc_expires' => tep_db_prepare_input($_POST['cc_expires']),
                           'shipping_method' => $shipping['title'],
                           'shipping_cost' => $shipping['cost'],
-                          'comments' => $GLOBALS['comments']);
+                          'comments' => $_SESSION['comments']);
 
       if (isset($GLOBALS[$payment]) && is_object($GLOBALS[$payment])) {
         $this->info['payment_method'] = $GLOBALS[$payment]->title;
