@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: japanese.php,v 1.2 2005/09/22 01:20:08 ryu Exp $
+  $Id: japanese.php,v 1.3 2006/02/05 11:36:35 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -62,7 +62,8 @@ define('TITLE', STORE_NAME);
 
 // geta information
 define('TEXT_GETA_LOGO', 'GETA');
-define('TEXT_GETA_INFORMATION', 'Ϣ۷׻󥸥ʣǣţԣˡפϡȶ(IPA)»ܤŪ󵻽Ѱȡפθ̤Ǥ ');
+define('TEXT_GETA_INFORMATION', '');
+//define('TEXT_GETA_INFORMATION', 'Ϣ۷׻󥸥ʣǣţԣˡפϡȶ(IPA)»ܤŪ󵻽Ѱȡפθ̤Ǥ ');
 
 // header text in includes/header.php
 define('HEADER_TITLE_CREATE_ACCOUNT', 'Ⱥ');
