@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: product_listing.php,v 1.2 2005/09/24 03:06:41 ryu Exp $
+  $Id: product_listing.php,v 1.3 2006/01/29 14:49:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -17,6 +17,9 @@
 <?php
   $listing_numrows_sql = $listing_sql;
   $listing_split = new splitPageResults($HTTP_GET_VARS['page'], MAX_DISPLAY_SEARCH_RESULTS, $listing_sql, $listing_numrows);
+  if (isset($option_search_engine_safe)) {
+    $listing_split->set_search_engine_safe($option_search_engine_safe);
+  }
 // fix counted products
   $listing_numrows = tep_db_query($listing_numrows_sql);
   $listing_numrows = tep_db_num_rows($listing_numrows);
@@ -136,7 +139,7 @@
             break;
           case 'PRODUCT_LIST_NAME':
             $lc_param = 'productListName';
-            if (!empty($HTTP_GET_VARS['manufacturers_id'])) {
+            if (isset($HTTP_GET_VARS['manufacturers_id']) && $HTTP_GET_VARS['manufacturers_id']) {
               $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'manufacturers_id=' . $HTTP_GET_VARS['manufacturers_id'] . '&products_id=' . $listing['products_id']) . '">' . $listing['products_name'] . '</a>';
             } else {
               $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, ($cPath ? 'cPath=' . $cPath . '&' : '') . 'products_id=' . $listing['products_id']) . '">' . $listing['products_name'] . '</a>';
@@ -212,7 +215,7 @@
             break;
           case 'PRODUCT_LIST_IMAGE':
             $lc_param = 'productListImage';
-            if (!empty($HTTP_GET_VARS['manufacturers_id'])) {
+            if (isset($HTTP_GET_VARS['manufacturers_id']) && $HTTP_GET_VARS['manufacturers_id']) {
               $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'manufacturers_id=' . $HTTP_GET_VARS['manufacturers_id'] . '&products_id=' . $listing['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $listing['products_image'], $listing['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a>';
             } else {
               $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, ($cPath ? 'cPath=' . $cPath . '&' : '') . 'products_id=' . $listing['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $listing['products_image'], $listing['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a>';
