@@ -268,7 +268,7 @@ ryuhei@secondbrain.co.jp
     } else {
       $sort_col = substr($HTTP_GET_VARS['sort'], 0 , 1);
       $sort_order = substr($HTTP_GET_VARS['sort'], 1);
-      $listing_sql .= ' order by ';
+      $listing_sql .= ' order by p.sort_order, ';
       switch ($column_list[$sort_col-1]) {
         case 'PRODUCT_LIST_MODEL':
           $listing_sql .= "p.products_model " . ($sort_order == 'd' ? 'desc' : '') . ", pd.products_name";
